@ECHO OFF
@REM WinUpdateToggler
@REM [ENG] De/Activates Windows Update and related settings on Windows 10.
@REM [ESP] Des/Activa Windows Update y ajustes relacionados en Windows 10.


:LANGUAGE_SETTINGS
SET IGNORE_SYSTEM_LANGUAGE=N
@REM [ENG] IGNORE_SYSTEM_LANGUAGE - The valid options are:
@REM    Y - Ignores the detected system language.
@REM    N - Use the detected system language. (Default setting)
@REM [ESP] IGNORE_SYSTEM_LANGUAGE - Las opciones vlidas son:
@REM    Y - Ignora el lenguaje detectado del sistema operativo.
@REM    N - Emplea el lenguaje detectado del sistema operativo. (Ajuste predeterminado)
SET FORCE_LANGUAGE=ENG
@REM [ENG] FORCE_LANGUAGE - Changes the language used in the script, including menu options, messages and command-line parameters. The valid options are:
@REM    ENG - English language. (Default setting)
@REM    ESP - Spanish language.
@REM    Note: You must change to "Y" the IGNORE_SYSTEM_LANGUAGE setting to force the selected language; otherwise the script will always try to detect the operating system language.
@REM [ESP] FORCE_LANGUAGE - Altera el lenguaje empleado en el script, incluyendo las opciones del men, mensajes y parmetros de lnea de comandos. Las opciones vlidas son:
@REM    ENG - Lenguaje ingls. (Default setting)
@REM    ESP - Lenguaje espaol.
@REM    Nota: Debe cambiar a "Y" el ajuste IGNORE_SYSTEM_LANGUAGE para poder forzar el lenguaje elegido; de otro modo el script siempre intentar detectar el lenguaje del sistema operativo.
GOTO LANGUAGE_DETECT


:USER_SETTINGS
@REM [ENG] You can change these settings if you know what you are doing.
@REM    These default settings affect both command-line and menu options.
@REM    The valid options for all are: %ON% and %OFF%.
@REM    SCHEDULED_TASKS can also use %IGNORE% - this will leave the setting as it was.
@REM [ESP] Puede cambiar estos ajustes si sabe lo que est haciendo.
@REM    Estos ajustes predeterminados afectan tanto a la lnea de comandos como a las opciones del men.
@REM    Las opciones vlidas para todos ellos son: %ON% y %OFF%.
@REM    SCHEDULED_TASKS puede emplear tambin %IGNORE% - esto har que el ajuste no sea alterado.
SET CHECK_UPDATES=%OFF%
SET SCHEDULED_TASKS=%IGNORE%
SET ADVANCED_OPTIONS_DEFAULT_STATE=%OFF%


:CONSTANTS
SET SCRIPT_NAME=WinUpdateToggler
SET VERSION=0.5
SET SEPARATOR_1=----------------------------------------------------------------------------------------------------
SET SEPARATOR_2=====================================================================================================
SET SEPARATOR_3=------------------------------------------------------------------------------
SET TAB=	%


:CHECK_WINDOWS_VERSION
SET WINDOWS_OK=0
FOR /F "tokens=4-5 delims=. " %%i IN ('ver') DO SET WINDOWS_VERSION=%%i.%%j
IF "%WINDOWS_VERSION%"=="10.0" SET WINDOWS_OK=1
IF %WINDOWS_OK% EQU 0 ECHO %CHECK_WINDOWS_1% & ECHO %EXITING% & PAUSE & EXIT 1


:CHECK_ADMIN
net session >NUL 2>&1
IF %ERRORLEVEL% NEQ 0 ECHO %CHECK_ADMIN_1% & ECHO %EXITING% & PAUSE & EXIT 1


:WINDOW_SETTINGS
COLOR 1B
FOR /F "tokens=2 delims=:" %%a IN ('MODE CON') DO FOR %%b IN (%%a) DO (
    IF NOT DEFINED LINES (
        SET "LINES=%%b"
        ) ELSE IF NOT DEFINED COLS SET "COLS=%%b"
    )
IF %COLS% LSS 100 MODE CON:COLS=100


:COMMAND_LINE
IF "%~1"=="" (
    SET WINDOWS_UPDATE=%IGNORE%
    SET DRIVERS_UPDATE=%IGNORE%
    SET ETHERNET_CONNECTION_METERED=%IGNORE%
    SET UPDATES_DELIVERY_P2P=%IGNORE%
    GOTO MENU_SETTINGS
    )

IF /I "%~1"=="-ENG" CALL :LANG_ENG_CMDLINE
IF /I "%~1"=="-ING" CALL :LANG_ENG_CMDLINE
IF /I "%~1"=="-ESP" CALL :LANG_ESP_CMDLINE
IF /I "%~1"=="-SPA" CALL :LANG_ESP_CMDLINE

FOR %%P IN (%*) DO (
    IF /I "%%P"=="-%CMDLINE_DU%%ON%" (SET DRIVERS_UPDATE=%ON%) & (SET ADVANCED_OPTIONS=%ON%)
    IF /I "%%P"=="-%CMDLINE_DU%%OFF%" (SET DRIVERS_UPDATE=%OFF%) & (SET ADVANCED_OPTIONS=%ON%)
    IF /I "%%P"=="-%CMDLINE_MC%%ON%" (SET ETHERNET_CONNECTION_METERED=%ON%) & (SET ADVANCED_OPTIONS=%ON%)
    IF /I "%%P"=="-%CMDLINE_MC%%OFF%" (SET ETHERNET_CONNECTION_METERED=%OFF%) & (SET ADVANCED_OPTIONS=%ON%)
    IF /I "%%P"=="-%CMDLINE_UD%%ON%" (SET UPDATES_DELIVERY_P2P=%ON%) & (SET ADVANCED_OPTIONS=%ON%)
    IF /I "%%P"=="-%CMDLINE_UD%%OFF%" (SET UPDATES_DELIVERY_P2P=%OFF%) & (SET ADVANCED_OPTIONS=%ON%)

    IF /I "%%P"=="-%CMDLINE_WU%%ON%" SET WINDOWS_UPDATE=%ON%
    IF /I "%%P"=="-%CMDLINE_WU%%OFF%" SET WINDOWS_UPDATE=%OFF%
    IF /I "%%P"=="-%CMDLINE_ST%%ON%" SET SCHEDULED_TASKS=%ON%
    IF /I "%%P"=="-%CMDLINE_ST%%OFF%" SET SCHEDULED_TASKS=%OFF%
    IF /I "%%P"=="-%CMDLINE_CU%%ON%" SET CHECK_UPDATES=%ON%
    )


:MENU_SETTINGS
IF "%WINDOWS_UPDATE%"=="%ON%" SET MENU_PADDING_1=%MENU_PADDING_WU_ON%
IF "%WINDOWS_UPDATE%"=="%OFF%" SET MENU_PADDING_1=%MENU_PADDING_WU_OFF%
IF "%WINDOWS_UPDATE%"=="%IGNORE%" SET MENU_PADDING_1=%MENU_PADDING_WU_IGNORE%
IF "%SCHEDULED_TASKS%"=="%ON%" SET MENU_PADDING_2=%MENU_PADDING_ST_ON%
IF "%SCHEDULED_TASKS%"=="%OFF%" SET MENU_PADDING_2=%MENU_PADDING_ST_OFF%
IF "%SCHEDULED_TASKS%"=="%IGNORE%" SET MENU_PADDING_2=%MENU_PADDING_ST_IGNORE%
IF "%CHECK_UPDATES%"=="%ON%" SET MENU_PADDING_3=%MENU_PADDING_CU_ON%
IF "%CHECK_UPDATES%"=="%OFF%" SET MENU_PADDING_3=%MENU_PADDING_CU_OFF%
IF "%DRIVERS_UPDATE%"=="%ON%" SET MENU_PADDING_6=%MENU_PADDING_DU_ON%
IF "%DRIVERS_UPDATE%"=="%OFF%" SET MENU_PADDING_6=%MENU_PADDING_DU_OFF%
IF "%DRIVERS_UPDATE%"=="%IGNORE%" SET MENU_PADDING_6=%MENU_PADDING_DU_IGNORE%
IF "%ETHERNET_CONNECTION_METERED%"=="%ON%" SET MENU_PADDING_7=%MENU_PADDING_MC_ON%
IF "%ETHERNET_CONNECTION_METERED%"=="%OFF%" SET MENU_PADDING_7=%MENU_PADDING_MC_OFF%
IF "%ETHERNET_CONNECTION_METERED%"=="%IGNORE%" SET MENU_PADDING_7=%MENU_PADDING_MC_IGNORE%
IF "%UPDATES_DELIVERY_P2P%"=="%ON%" SET MENU_PADDING_8=%MENU_PADDING_UD_ON%
IF "%UPDATES_DELIVERY_P2P%"=="%OFF%" SET MENU_PADDING_8=%MENU_PADDING_UD_OFF%
IF "%UPDATES_DELIVERY_P2P%"=="%IGNORE%" SET MENU_PADDING_8=%MENU_PADDING_UD_IGNORE%

IF "%ADVANCED_OPTIONS%"=="%ON%" (
    IF NOT "%~1"=="" GOTO HUB_AO
    )
IF NOT "%~1"=="" GOTO HUB

IF "%ADVANCED_OPTIONS_DEFAULT_STATE%"=="%ON%" (SET ADVANCED_OPTIONS=%ON%) & (SET MENU_0=%MENU_0_ON%) ELSE (SET ADVANCED_OPTIONS=%OFF%) & (SET MENU_0=%MENU_0_OFF%)
GOTO MENU


:MENU_MARK_DEFAULTS
IF "%WINDOWS_UPDATE%"=="%ON%" SET WINDOWS_UPDATE_MARK=[*]
IF "%WINDOWS_UPDATE%"=="%OFF%" SET WINDOWS_UPDATE_MARK=
IF "%SCHEDULED_TASKS%"=="%ON%" SET SCHEDULED_TASKS_MARK=[*]
IF "%SCHEDULED_TASKS%"=="%OFF%" SET SCHEDULED_TASKS_MARK=
IF "%CHECK_UPDATES%"=="%OFF%" SET CHECK_UPDATES_MARK=
IF "%CHECK_UPDATES%"=="%ON%" (
    IF "%WINDOWS_UPDATE%"=="%ON%" SET CHECK_UPDATES_MARK=
    IF "%WINDOWS_UPDATE%"=="%OFF%" SET CHECK_UPDATES_MARK=[?!]
    )
IF "%DRIVERS_UPDATE%"=="%ON%" SET DRIVERS_UPDATE_MARK=[*]
IF "%DRIVERS_UPDATE%"=="%OFF%" SET DRIVERS_UPDATE_MARK=
IF "%ETHERNET_CONNECTION_METERED%"=="%IGNORE%" SET ETHERNET_CONNECTION_METERED_MARK=
IF "%ETHERNET_CONNECTION_METERED%"=="%OFF%" SET ETHERNET_CONNECTION_METERED_MARK=[*]
IF "%UPDATES_DELIVERY_P2P%"=="%ON%" SET UPDATES_DELIVERY_P2P_MARK=[*]
IF "%UPDATES_DELIVERY_P2P%"=="%OFF%" SET UPDATES_DELIVERY_P2P_MARK=
EXIT /B


:MENU
CALL :MENU_MARK_DEFAULTS
CLS
ECHO %SEPARATOR_2%
ECHO  %SCRIPT_NAME% v%VERSION%
ECHO %SEPARATOR_2%
ECHO.
ECHO %TAB% %MENU_TITLE_1%
ECHO %TAB% 1. %MENU_1% %MENU_PADDING_1% [ %WINDOWS_UPDATE% ] %WINDOWS_UPDATE_MARK%
ECHO %TAB% 2. %MENU_2% %MENU_PADDING_2% [ %SCHEDULED_TASKS% ] %SCHEDULED_TASKS_MARK%
ECHO %TAB% 3. %MENU_3% %MENU_PADDING_3% [ %CHECK_UPDATES% ] %CHECK_UPDATES_MARK%
ECHO %TAB% 4. %MENU_APPLY_CO%
ECHO %TAB% 5. %MENU_EXIT%
ECHO.
IF "%ADVANCED_OPTIONS%"=="%ON%" ECHO %TAB% %SEPARATOR_3%
IF "%ADVANCED_OPTIONS%"=="%ON%" ECHO %TAB% %MENU_TITLE_2%
IF "%ADVANCED_OPTIONS%"=="%ON%" ECHO %TAB% - %MENU_AO_INFO_1%
IF "%ADVANCED_OPTIONS%"=="%ON%" ECHO %TAB% - %MENU_AO_INFO_2%
IF "%ADVANCED_OPTIONS%"=="%ON%" ECHO %TAB% - %MENU_AO_INFO_3%
IF "%ADVANCED_OPTIONS%"=="%ON%" ECHO %TAB% - %MENU_AO_INFO_4%
IF "%ADVANCED_OPTIONS%"=="%ON%" ECHO %TAB% - %MENU_AO_INFO_5%
IF "%ADVANCED_OPTIONS%"=="%ON%" ECHO %TAB% - %MENU_AO_INFO_6%
IF "%ADVANCED_OPTIONS%"=="%ON%" ECHO %TAB% %SEPARATOR_3%
IF "%ADVANCED_OPTIONS%"=="%ON%" ECHO %TAB% 6. %MENU_6% %MENU_PADDING_6% [ %DRIVERS_UPDATE% ] %DRIVERS_UPDATE_MARK%
IF "%ADVANCED_OPTIONS%"=="%ON%" ECHO %TAB% 7. %MENU_7% %MENU_PADDING_7% [ %ETHERNET_CONNECTION_METERED% ] %ETHERNET_CONNECTION_METERED_MARK%
IF "%ADVANCED_OPTIONS%"=="%ON%" ECHO %TAB% 8. %MENU_8% %MENU_PADDING_8% [ %UPDATES_DELIVERY_P2P% ] %UPDATES_DELIVERY_P2P_MARK%
IF "%ADVANCED_OPTIONS%"=="%ON%" ECHO %TAB% 9. %MENU_APPLY_AO%
ECHO %TAB% 0. %MENU_0%
ECHO.
ECHO %MENU_INFO_1%
IF "%ADVANCED_OPTIONS%"=="%ON%" ECHO %MENU_INFO_2%
ECHO %MENU_INFO_3%
set /p SELECTION=%MENU_PROMPT%
set SELECTION=%SELECTION:~0,1%
IF "%SELECTION%"=="1" GOTO TOGGLE_WU
IF "%SELECTION%"=="2" GOTO TOGGLE_ST
IF "%SELECTION%"=="3" GOTO TOGGLE_CU
IF "%SELECTION%"=="4" GOTO HUB
IF "%SELECTION%"=="5" GOTO END
IF "%ADVANCED_OPTIONS%"=="%ON%" (
    IF "%SELECTION%"=="6" GOTO TOGGLE_DU
    IF "%SELECTION%"=="7" GOTO TOGGLE_MC
    IF "%SELECTION%"=="8" GOTO TOGGLE_UD
    IF "%SELECTION%"=="9" GOTO HUB_AO
    )
IF "%SELECTION%"=="0" GOTO TOGGLE_AO
ECHO "%SELECTION%" %MENU_ERROR_INFO%
TIMEOUT 2
GOTO MENU


:TOGGLE_WU
IF "%WINDOWS_UPDATE%"=="%IGNORE%" (
    SET WINDOWS_UPDATE=%ON%
    SET MENU_PADDING_1=%MENU_PADDING_WU_ON%
    GOTO MENU
    )
IF "%WINDOWS_UPDATE%"=="%ON%" (
    SET WINDOWS_UPDATE=%OFF%
    SET MENU_PADDING_1=%MENU_PADDING_WU_OFF%
    GOTO MENU
    )
IF "%WINDOWS_UPDATE%"=="%OFF%" (
    SET WINDOWS_UPDATE=%IGNORE%
    SET MENU_PADDING_1=%MENU_PADDING_WU_IGNORE%
    GOTO MENU
    )


:TOGGLE_ST
IF "%SCHEDULED_TASKS%"=="%IGNORE%" (
    SET SCHEDULED_TASKS=%ON%
    SET MENU_PADDING_2=%MENU_PADDING_ST_ON%
    GOTO MENU
    )
IF "%SCHEDULED_TASKS%"=="%ON%" (
    SET SCHEDULED_TASKS=%OFF%
    SET MENU_PADDING_2=%MENU_PADDING_ST_OFF%
    GOTO MENU
    )
IF "%SCHEDULED_TASKS%"=="%OFF%" (
    SET SCHEDULED_TASKS=%IGNORE%
    SET MENU_PADDING_2=%MENU_PADDING_ST_IGNORE%
    GOTO MENU
    )


:TOGGLE_CU
IF "%CHECK_UPDATES%"=="%ON%" (
    SET CHECK_UPDATES=%OFF%
    SET MENU_PADDING_3=%MENU_PADDING_CU_OFF%
    GOTO MENU
    )
SET CHECK_UPDATES=%ON%
SET MENU_PADDING_3=%MENU_PADDING_CU_ON%
GOTO MENU


:TOGGLE_DU
IF "%DRIVERS_UPDATE%"=="%IGNORE%" (
    SET DRIVERS_UPDATE=%ON%
    SET MENU_PADDING_6=%MENU_PADDING_DU_ON%
    GOTO MENU
    )
IF "%DRIVERS_UPDATE%"=="%ON%" (
    SET DRIVERS_UPDATE=%OFF%
    SET MENU_PADDING_6=%MENU_PADDING_DU_OFF%
    GOTO MENU
    )
IF "%DRIVERS_UPDATE%"=="%OFF%" (
    SET DRIVERS_UPDATE=%IGNORE%
    SET MENU_PADDING_6=%MENU_PADDING_DU_IGNORE%
    GOTO MENU
    )


:TOGGLE_MC
IF "%ETHERNET_CONNECTION_METERED%"=="%IGNORE%" (
    SET ETHERNET_CONNECTION_METERED=%ON%
    SET MENU_PADDING_7=%MENU_PADDING_MC_ON%
    GOTO MENU
    )
IF "%ETHERNET_CONNECTION_METERED%"=="%ON%" (
    SET ETHERNET_CONNECTION_METERED=%OFF%
    SET MENU_PADDING_7=%MENU_PADDING_MC_OFF%
    GOTO MENU
    )
IF "%ETHERNET_CONNECTION_METERED%"=="%OFF%" (
    SET ETHERNET_CONNECTION_METERED=%IGNORE%
    SET MENU_PADDING_7=%MENU_PADDING_MC_IGNORE%
    GOTO MENU
    )


:TOGGLE_UD
IF "%UPDATES_DELIVERY_P2P%"=="%IGNORE%" (
    SET UPDATES_DELIVERY_P2P=%ON%
    SET MENU_PADDING_8=%MENU_PADDING_UD_ON%
    GOTO MENU
    )
IF "%UPDATES_DELIVERY_P2P%"=="%ON%" (
    SET UPDATES_DELIVERY_P2P=%OFF%
    SET MENU_PADDING_8=%MENU_PADDING_UD_OFF%
    GOTO MENU
    )
IF "%UPDATES_DELIVERY_P2P%"=="%OFF%" (
    SET UPDATES_DELIVERY_P2P=%IGNORE%
    SET MENU_PADDING_8=%MENU_PADDING_UD_IGNORE%
    GOTO MENU
    )


:TOGGLE_AO
IF "%ADVANCED_OPTIONS%"=="%ON%" (
    SET ADVANCED_OPTIONS=%OFF%
    SET MENU_0=%MENU_0_OFF%
    GOTO MENU
    )
SET ADVANCED_OPTIONS=%ON%
SET MENU_0=%MENU_0_ON%
GOTO MENU


:HUB
CLS
ECHO %SEPARATOR_2%
ECHO  %SCRIPT_NAME% v%VERSION%
ECHO %SEPARATOR_2%
ECHO.
ECHO %TAB% 1. %MENU_1% %MENU_PADDING_1% [ %WINDOWS_UPDATE% ]
ECHO %TAB% 2. %MENU_2% %MENU_PADDING_2% [ %SCHEDULED_TASKS% ]
ECHO %TAB% 3. %MENU_3% %MENU_PADDING_3% [ %CHECK_UPDATES% ]
TIMEOUT 2 >NUL

IF "%WINDOWS_UPDATE%"=="%ON%" GOTO WINDOWS_UPDATE_ON
IF "%WINDOWS_UPDATE%"=="%OFF%" GOTO WINDOWS_UPDATE_OFF
IF "%SCHEDULED_TASKS%"=="%ON%" GOTO SCHEDULED_TASKS_ON
IF "%SCHEDULED_TASKS%"=="%OFF%" GOTO SCHEDULED_TASKS_OFF
IF "%CHECK_UPDATES%"=="%ON%" GOTO CHECK_UPDATES
GOTO END


:HUB_AO
CLS
ECHO %SEPARATOR_2%
ECHO  %SCRIPT_NAME% v%VERSION%
ECHO %SEPARATOR_2%
ECHO.
ECHO %TAB% 6. %MENU_6% %MENU_PADDING_6% [ %DRIVERS_UPDATE% ]
ECHO %TAB% 7. %MENU_7% %MENU_PADDING_7% [ %ETHERNET_CONNECTION_METERED% ]
ECHO %TAB% 8. %MENU_8% %MENU_PADDING_8% [ %UPDATES_DELIVERY_P2P% ]
TIMEOUT 2 >NUL

CALL :DRIVERS_UPDATE
CALL :ETHERNET_CONNECTION_METERED
CALL :UPDATES_DELIVERY_P2P
GOTO END


:WINDOWS_UPDATE_ON
ECHO.
ECHO.
ECHO %SEPARATOR_2%
ECHO %TAB% %WINDOWS_UPDATE_ON_0%
ECHO %SEPARATOR_2%
ECHO.
ECHO %WINDOWS_UPDATE_ON_1%
ECHO.
sc query lanmanworkstation >NUL 2>&1 && sc config lanmanworkstation start= auto
sc query lanmanworkstation 2>&1 | FINDSTR /I stopped >NUL 2>&1 && net start lanmanworkstation
sc query eventlog >NUL 2>&1 && sc config eventlog start= auto
sc query eventlog 2>&1 | FINDSTR /I stopped >NUL 2>&1 && net start eventlog
sc query dhcp >NUL 2>&1 && sc config dhcp start= auto
sc query dhcp 2>&1 | FINDSTR /I stopped >NUL 2>&1 && net start dhcp
ECHO %SEPARATOR_1%


ECHO.
ECHO %TAB% %WINDOWS_UPDATE_ON_2%
ECHO.
sc query TrustedInstaller >NUL 2>&1 && sc config TrustedInstaller start= demand
sc query TrustedInstaller 2>&1 | FINDSTR /I stopped >NUL 2>&1 && net start TrustedInstaller

ECHO.
ECHO %TAB% %WINDOWS_UPDATE_ON_3%
ECHO.
sc query MpsSvc >NUL 2>&1 && sc config MpsSvc start= auto
sc query MpsSvc 2>&1 | FINDSTR /I stopped >NUL 2>&1 && net start MpsSvc
sc query BFE >NUL 2>&1 && sc config BFE start= auto
sc query BFE 2>&1 | FINDSTR /I stopped >NUL 2>&1 && net start BFE

ECHO.
ECHO %TAB% %WINDOWS_UPDATE_ON_4%
ECHO.
sc query CryptSvc >NUL 2>&1 && sc config CryptSvc start= auto
sc query CryptSvc 2>&1 | FINDSTR /I stopped >NUL 2>&1 && net start CryptSvc

ECHO.
ECHO %TAB% %WINDOWS_UPDATE_ON_5%
ECHO.
sc query AppIDSvc >NUL 2>&1 && sc config AppIDSvc start= demand
sc query AppIDSvc 2>&1 | FINDSTR /I stopped >NUL 2>&1 && net start AppIDSvc

ECHO.
ECHO %TAB% %WINDOWS_UPDATE_ON_6%
ECHO.
sc query wuauserv >NUL 2>&1 && sc config W32Time start= demand
sc query W32Time 2>&1 | FINDSTR /I stopped >NUL 2>&1 && net start W32Time
W32TM /config /syncfromflags:manual /manualpeerlist:"0.pool.ntp.org,0x8 1.pool.ntp.org,0x8 2.pool.ntp.org,0x8 3.pool.ntp.org,0x8" /update

ECHO.
ECHO %TAB% %WINDOWS_UPDATE_ON_7%
ECHO.
sc query BITS >NUL 2>&1 && sc config BITS start= auto
sc query BITS 2>&1 | FINDSTR /I stopped >NUL 2>&1 && net start BITS
sc query wuauserv >NUL 2>&1 && sc config wuauserv start= demand
sc query wuauserv 2>&1 | FINDSTR /I stopped >NUL 2>&1 && net start wuauserv
ECHO %SEPARATOR_1%

GOTO SCHEDULED_TASKS


:WINDOWS_UPDATE_OFF
ECHO.
ECHO.
ECHO %SEPARATOR_2%
ECHO %TAB% %WINDOWS_UPDATE_OFF_0%
ECHO %SEPARATOR_2%
ECHO.
ECHO %TAB% %WINDOWS_UPDATE_OFF_1%
ECHO.
sc query BITS >NUL 2>&1 && sc config BITS start= disabled
sc query BITS 2>&1 | FINDSTR /I running >NUL 2>&1 && net stop BITS
sc query wuauserv >NUL 2>&1 && sc config wuauserv start= disabled
sc query wuauserv 2>&1 | FINDSTR /I running >NUL 2>&1 && net stop wuauserv
ECHO %SEPARATOR_1%

GOTO SCHEDULED_TASKS


:SCHEDULED_TASKS
IF "%SCHEDULED_TASKS%"=="%ON%" GOTO SCHEDULED_TASKS_ON
IF "%SCHEDULED_TASKS%"=="%OFF%" GOTO SCHEDULED_TASKS_OFF
IF "%CHECK_UPDATES%"=="%ON%" GOTO CHECK_UPDATES
IF "%SCHEDULED_TASKS%"=="%IGNORE%" GOTO END


:SCHEDULED_TASKS_ON
ECHO.
ECHO.
ECHO %SEPARATOR_2%
ECHO %TAB% %SCHEDULED_TASKS_ON_0%
ECHO %SEPARATOR_2%
schtasks /change /enable /tn "\Microsoft\Windows\WindowsUpdate\Scheduled Start"
schtasks /change /enable /tn "\Microsoft\Windows\UpdateOrchestrator\Schedule Scan"
schtasks /change /enable /tn "\Microsoft\Windows\UpdateOrchestrator\Maintenance Install"
schtasks /change /enable /tn "\Microsoft\Windows\UpdateOrchestrator\Refresh Settings"
schtasks /change /enable /tn "\Microsoft\Windows\UpdateOrchestrator\Reboot"
ECHO %SEPARATOR_1%

IF "%CHECK_UPDATES%"=="%ON%" GOTO CHECK_UPDATES
GOTO END


:SCHEDULED_TASKS_OFF
ECHO.
ECHO.
ECHO %SEPARATOR_2%
ECHO %TAB% %SCHEDULED_TASKS_OFF_0%
ECHO %SEPARATOR_2%
schtasks /change /disable /tn "\Microsoft\Windows\WindowsUpdate\Scheduled Start"
schtasks /change /disable /tn "\Microsoft\Windows\UpdateOrchestrator\Schedule Scan"
schtasks /change /disable /tn "\Microsoft\Windows\UpdateOrchestrator\Maintenance Install"
schtasks /change /disable /tn "\Microsoft\Windows\UpdateOrchestrator\Refresh Settings"
schtasks /change /disable /tn "\Microsoft\Windows\UpdateOrchestrator\Reboot"
ECHO %SEPARATOR_1%

IF "%CHECK_UPDATES%"=="%ON%" GOTO CHECK_UPDATES
GOTO END


:CHECK_UPDATES
ECHO.
ECHO.
ECHO %SEPARATOR_2%
ECHO %TAB% %CHECK_UPDATES_1%
ECHO %SEPARATOR_2%
start ms-settings:windowsupdate-action
GOTO END


:DRIVERS_UPDATE
SET REGKEY=HKEY_LOCAL_MACHINE\SOFTWARE\Policies\Microsoft\Windows\WindowsUpdate
IF "%DRIVERS_UPDATE%"=="%ON%" reg delete "%REGKEY%" /f /v ExcludeWUDriversInQualityUpdate
IF "%DRIVERS_UPDATE%"=="%OFF%" reg add "%REGKEY%" /f /v ExcludeWUDriversInQualityUpdate /t reg_dword /d 1
EXIT /B


:ETHERNET_CONNECTION_METERED
SET REGKEY=HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\Windows NT\CurrentVersion\NetworkList\DefaultMediaCost
IF "%ETHERNET_CONNECTION_METERED%"=="%ON%" reg add "%REGKEY%" /f /v Ethernet /t reg_dword /d 2
IF "%ETHERNET_CONNECTION_METERED%"=="%OFF%" reg add "%REGKEY%" /f /v Ethernet /t reg_dword /d 1
EXIT /B


:UPDATES_DELIVERY_P2P
SET REGKEY=HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\Windows\CurrentVersion\DeliveryOptimization\Config
IF "%UPDATES_DELIVERY_P2P%"=="%ON%" reg add "%REGKEY%" /f /v DownloadMode /t reg_dword /d 3
IF "%UPDATES_DELIVERY_P2P%"=="%OFF%" reg add "%REGKEY%" /f /v DownloadMode /t reg_dword /d 0
IF "%UPDATES_DELIVERY_P2P%"=="%ON%" reg add "%REGKEY%" /f /v DODownloadMode /t reg_dword /d 3
IF "%UPDATES_DELIVERY_P2P%"=="%OFF%" reg add "%REGKEY%" /f /v DODownloadMode /t reg_dword /d 0
EXIT /B


:END
ECHO.
ECHO.
ECHO %TAB% [ %END_1% ]
PAUSE >NUL
EXIT 0


:LANGUAGE_DETECT
IF /I "%IGNORE_SYSTEM_LANGUAGE%"=="Y" GOTO LANG_%FORCE_LANGUAGE%
ver /?|FIND /I "muestra" >NUL 2>&1
IF %ERRORLEVEL% EQU 0 (SET LANGUAGE=ESP) ELSE (SET LANGUAGE=ENG)
GOTO LANG_%LANGUAGE%


:LANG_ENG
SET ON=ON
SET OFF=OFF
SET IGNORE=IGNORE
SET CHECK_WINDOWS_1=%SCRIPT_NAME% v%VERSION% requires Windows 10.
SET EXITING=Exiting.
SET CHECK_ADMIN_1=%SCRIPT_NAME% v%VERSION% requires administrative privileges to work properly.
SET MENU_TITLE_1=COMMON OPTIONS
SET MENU_TITLE_2=ADVANCED OPTIONS
SET MENU_1=Windows Updates:
SET MENU_2=Related scheduled tasks:
SET MENU_3=Check updates now:
SET MENU_6=Device drivers update on Windows Update:
SET MENU_7=Set wired connection (ethernet) as metered:
SET MENU_8=Windows Updates delivering includes P2P:
SET MENU_APPLY_CO=Apply changes!
SET MENU_APPLY_AO=Apply advanced options!
SET MENU_EXIT=Exit
SET MENU_0_ON=Disable advanced options
SET MENU_0_OFF=Enable advanced options
SET MENU_INFO_1=You can toggle an option (1-3), apply the indicated settings (4) or exit (5)
SET MENU_INFO_2=Also, you can toggle the advanced options (6-7) or apply the changes (8)
SET MENU_INFO_3=NOTE: Options marked with [*] denote a Windows default setting.
SET MENU_PROMPT=Select a number: %
SET MENU_ERROR_INFO=is not a valid selection.
SET MENU_AO_INFO_1=Don't touch them if you don't know exactly what they do.
SET MENU_AO_INFO_2=The OS will need to identify the changes after you apply any one.
SET MENU_AO_INFO_3=For this to happen you have to log-off or reboot the computer.
SET MENU_AO_INFO_4=Following that, the changes will be activated.
SET MENU_AO_INFO_5=Otherwise they won't get applied in the common options if you need them to.
SET MENU_AO_INFO_6=REMEMBER: 1) apply, 2) identify, 3) common options.
SET MENU_PADDING_WU_ON=                                                   %
SET MENU_PADDING_WU_OFF=                                                  %
SET MENU_PADDING_WU_IGNORE=                                               %
SET MENU_PADDING_ST_ON=                                           %
SET MENU_PADDING_ST_OFF=                                          %
SET MENU_PADDING_ST_IGNORE=                                       %
SET MENU_PADDING_CU_ON=                                                 %
SET MENU_PADDING_CU_OFF=                                                %
SET MENU_PADDING_DU_ON=                           %
SET MENU_PADDING_DU_OFF=                          %
SET MENU_PADDING_DU_IGNORE=                       %
SET MENU_PADDING_MC_ON=                        %
SET MENU_PADDING_MC_OFF=                       %
SET MENU_PADDING_MC_IGNORE=                    %
SET MENU_PADDING_UD_ON=                           %
SET MENU_PADDING_UD_OFF=                          %
SET MENU_PADDING_UD_IGNORE=                       %
SET WINDOWS_UPDATE_ON_0=Enabling Windows Update...
SET WINDOWS_UPDATE_ON_1=Windows Update required services
SET WINDOWS_UPDATE_ON_2=Windows Modules Installer service
SET WINDOWS_UPDATE_ON_3=Windows Firewall related services
SET WINDOWS_UPDATE_ON_4=Cryptographic service
SET WINDOWS_UPDATE_ON_5=Application Identity
SET WINDOWS_UPDATE_ON_6=Windows Time service
SET WINDOWS_UPDATE_ON_7=Windows Update services
SET WINDOWS_UPDATE_OFF_0=Disabling Windows Update...
SET WINDOWS_UPDATE_OFF_1=Windows Update services
SET SCHEDULED_TASKS_ON_0=Enabling/restoring Windows Update related tasks for the Task Scheduler...
SET SCHEDULER_TASKS_OFF_0=Disabling Windows Update related tasks for the Task Scheduler...
SET CHECK_UPDATES_1=Checking for updates...
SET END_1=Finished. Press any key to exit.
CALL :LANG_ENG_CMDLINE
GOTO USER_SETTINGS


:LANG_ENG_CMDLINE
SET CMDLINE_WU=WindowsUpdate
SET CMDLINE_ST=ScheduledTasks
SET CMDLINE_CU=CheckUpdates
SET CMDLINE_DU=DriversWindowsUpdate
SET CMDLINE_MC=EthernetConnectionMetered
SET CMDLINE_UD=UpdatesDeliveryP2P
EXIT /B


:LANG_ESP
CHCP 1252 >NUL
SET ON=ACTIVADO
SET OFF=DESACTIVADO
SET IGNORE=IGNORAR
SET CHECK_WINDOWS_1=%SCRIPT_NAME% v%VERSION% requiere Windows 10.
SET EXITING=Saliendo.
SET CHECK_ADMIN_1=%SCRIPT_NAME% v%VERSION% requiere permisos administrativos para funcionar correctamente.
SET MENU_TITLE_1=OPCIONES COMUNES
SET MENU_TITLE_2=OPCIONES AVANZADAS
SET MENU_1=Actualizaciones de Windows:
SET MENU_2=Tareas programadas relacionadas:
SET MENU_3=Comprobar actualizaciones ahora:
SET MENU_6=Instalar controladores mediante Windows Update:
SET MENU_7=Conexin cableada (ethernet) de uso medido:
SET MENU_8=Distribucin de actualizaciones de Windows incluyendo P2P:
SET MENU_APPLY_CO=Aplicar cambios!
SET MENU_APPLY_AO=Aplicar opciones avanzadas!
SET MENU_EXIT=Salir
SET MENU_0_ON=Oculta las opciones avanzadas
SET MENU_0_OFF=Muestra las opciones avanzadas
SET MENU_INFO_1=Puede conmutar una opcin (1-3), aplicar las opciones indicadas (4) o salir (5)
SET MENU_INFO_2=Adems, puede conmutar una opcin avanzada (6-7) o aplicar los cambios (8)
SET MENU_INFO_3=NOTA: Las opciones marcadas con [*] denotan un valor predeterminado de Windows.
SET MENU_PROMPT=Elija un nmero: %
SET MENU_ERROR_INFO=no es una eleccin vlida.
SET MENU_AO_INFO_1=No las cambie si no sabe exactamente lo que hacen.
SET MENU_AO_INFO_2=El sistema necesitar identificar los cambios realizados.
SET MENU_AO_INFO_3=Tras aplicar, tiene que cerrar sesin o reiniciar el sistema.
SET MENU_AO_INFO_4=Despus de esto, los cambios estarn activados.
SET MENU_AO_INFO_5=De otro modo no se podrn emplear en las opciones comunes.
SET MENU_AO_INFO_6=RECUERDE: 1) aplique, 2) identifique, 3) opciones comunes.
SET MENU_PADDING_WU_ON=                                  %
SET MENU_PADDING_WU_OFF=                               %
SET MENU_PADDING_WU_IGNORE=                                   %
SET MENU_PADDING_ST_ON=                             %
SET MENU_PADDING_ST_OFF=                          %
SET MENU_PADDING_ST_IGNORE=                              %
SET MENU_PADDING_CU_ON=                             %
SET MENU_PADDING_CU_OFF=                          %
SET MENU_PADDING_DU_ON=              %
SET MENU_PADDING_DU_OFF=           %
SET MENU_PADDING_DU_IGNORE=               %
SET MENU_PADDING_MC_ON=                  %
SET MENU_PADDING_MC_OFF=               %
SET MENU_PADDING_MC_IGNORE=                   %
SET MENU_PADDING_UD_ON=   %
SET MENU_PADDING_UD_OFF=%
SET MENU_PADDING_UD_IGNORE=    %
SET WINDOWS_UPDATE_ON_0=Habilitando Windows Update...
SET WINDOWS_UPDATE_ON_1=Servicios relacionados con Windows Update
SET WINDOWS_UPDATE_ON_2=Servicio Instalador de Mdulos de Windows
SET WINDOWS_UPDATE_ON_3=Servicios relacionados con el Cortafuegos de Windows
SET WINDOWS_UPDATE_ON_4=Servicio de criptografa
SET WINDOWS_UPDATE_ON_5=Servicio de Identidad de aplicacin
SET WINDOWS_UPDATE_ON_6=Servicio de Hora de Windows
SET WINDOWS_UPDATE_ON_7=Servicios de Windows Update
SET WINDOWS_UPDATE_OFF_0=Deshabilitando Windows Update...
SET WINDOWS_UPDATE_OFF_1=Servicios de Windows Update
SET SCHEDULED_TASKS_ON_0=Habilitando/restaurando las relacionadas con Windows Update en el Programador de Tareas...
SET SCHEDULED_TASKS_OFF_0=Deshabilitando las tareas relacionadas con Windows Update en el Programador de Tareas...
SET CHECK_UPDATES_1=Comprobando si hay actualizaciones...
SET END_1=Terminado. Pulse una tecla para salir.
CALL :LANG_ESP_CMDLINE
GOTO USER_SETTINGS


:LANG_ESP_CMDLINE
SET CMDLINE_WU=WindowsUpdate
SET CMDLINE_ST=TareasProgramadas
SET CMDLINE_CU=ComprobarActualizaciones
SET CMDLINE_DU=ControladoresWindowsUpdate
SET CMDLINE_MC=EthernetUsoMedido
SET CMDLINE_UD=EntregaDeActualizacionesP2P
EXIT /B

